@@ -47,7 +47,7 @@ use crate::{
 ///
 /// ```
 ///
-#[derive(Clone, Copy, Debug, PartialEq, PartialOrd)]
+#[derive(Clone, Copy, Debug, PartialEq, PartialOrd, Eq, Hash)]
 pub struct Header {
     id: u16,
     message_type: MessageType,
@@ -69,10 +69,12 @@ impl fmt::Display for Header {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> Result<(), fmt::Error> {
         write!(
             f,
-            "{id}:{flags}:{code:?}:{answers}/{authorities}/{additionals}",
+            "{id}:{message_type}:{flags}:{code:?}:{op_code}:{answers}/{authorities}/{additionals}",
             id = self.id,
+            message_type = self.message_type,
             flags = self.flags(),
             code = self.response_code,
+            op_code = self.op_code,
             answers = self.answer_count,
             authorities = self.name_server_count,
             additionals = self.additional_count,
@@ -81,7 +83,7 @@ impl fmt::Display for Header {
 }
 
 /// Message types are either Query (also Update) or Response
-#[derive(Debug, PartialEq, PartialOrd, Copy, Clone)]
+#[derive(Debug, PartialEq, Eq, PartialOrd, Copy, Clone, Hash)]
 pub enum MessageType {
     /// Queries are Client requests, these are either Queries or Updates
     Query,
@@ -92,8 +94,8 @@ pub enum MessageType {
 impl fmt::Display for MessageType {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> Result<(), fmt::Error> {
         let s = match self {
-            MessageType::Query => "QUERY",
-            MessageType::Response => "RESPONSE",
+            Self::Query => "QUERY",
+            Self::Response => "RESPONSE",
         };
 
         f.write_str(s)
@@ -101,7 +103,7 @@ impl fmt::Display for MessageType {
 }
 
 /// All the flags of the request/response header
-#[derive(Clone, Copy)]
+#[derive(Clone, Copy, PartialEq, Eq, Hash)]
 pub struct Flags {
     authoritative: bool,
     truncation: bool,
@@ -176,7 +178,7 @@ impl Header {
     /// Construct a new header based off the request header. This copies over the RD (recursion-desired)
     ///   and CD (checking-disabled), as well as the op_code and id of the request.
     ///
-    /// See https://datatracker.ietf.org/doc/html/rfc6895#section-2
+    /// See <https://datatracker.ietf.org/doc/html/rfc6895#section-2>
     ///
     /// ```text
     /// The AA, TC, RD, RA, and CD bits are each theoretically meaningful
@@ -260,13 +262,13 @@ impl Header {
         self
     }
 
-    /// Specifies that the data is authentic, i.e. the resolver believes all data to be valid through DNSSec
+    /// Specifies that the data is authentic, i.e. the resolver believes all data to be valid through DNSSEC
     pub fn set_authentic_data(&mut self, authentic_data: bool) -> &mut Self {
         self.authentic_data = authentic_data;
         self
     }
 
-    /// Used during recursive resolution to specified if a resolver should or should not validate DNSSec signatures
+    /// Used during recursive resolution to specified if a resolver should or should not validate DNSSEC signatures
     pub fn set_checking_disabled(&mut self, checking_disabled: bool) -> &mut Self {
         self.checking_disabled = checking_disabled;
         self
